# vim: set ts=4 sw=4 et:

# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.links2linux.org/

%define soname 0

%if 0%{?suse_version} <= 1120
%define gtk1 1
%endif

Name:           lame
Version:        3.99.5
Release:        1013.2
License:        LGPL-2.0+
URL:            http://lame.sourceforge.net/
Summary:        LAME Ain't an MP3 Encoder
Group:          Productivity/Multimedia/Sound/Editors and Convertors
Source:         http://prdownloads.sourceforge.net/lame/lame-%{version}.tar.gz
Source99:       lame-rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%ifarch %{ix86}
BuildRequires:  nasm
%endif
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
%if 0%{?gtk1}
BuildRequires:  gtk-devel
%else
BuildRequires:  pkgconfig(gtk+-2.0)
%endif
Requires:       libmp3lame%{soname} >= %{version}

%description
LAME is an educational tool to be used for learning about MP3 encoding.
The goal of the LAME project is to use the open source model to improve the
psycho acoustics, noise shaping and speed of MP3.
Another goal of the LAME project is to use these improvements for the basis of
a patent free audio compression codec for the GNU project.

%package doc
Summary:        LAME Ain't an MP3 Encoder (Documentation)
Group:          Productivity/Multimedia/Sound/Editors and Convertors
Requires:       %{name} = %{version}

%description doc
LAME is an educational tool to be used for learning about MP3 encoding.
The goal of the LAME project is to use the open source model to improve the
psycho acoustics, noise shaping and speed of MP3.
Another goal of the LAME project is to use these improvements for the basis of
a patent free audio compression codec for the GNU project.

This package contains additional documentation files in
  %{_defaultdocdir}/%{name}/

%package -n libmp3lame%{soname}
Summary:        LAME Ain't an MP3 Encoder
Group:          System/Libraries

%description -n libmp3lame%{soname}
LAME is an educational tool to be used for learning about MP3 encoding.
The goal of the LAME project is to use the open source model to improve the
psycho acoustics, noise shaping and speed of MP3.
Another goal of the LAME project is to use these improvements for the basis of
a patent free audio compression codec for the GNU project.

%package -n libmp3lame-devel
Summary:        LAME Ain't an MP3 Encoder
Group:          Development/Libraries/C and C++
Requires:       libmp3lame%{soname} = %{version}

%description -n libmp3lame-devel
LAME is an educational tool to be used for learning about MP3 encoding.
The goal of the LAME project is to use the open source model to improve the
psycho acoustics, noise shaping and speed of MP3.
Another goal of the LAME project is to use these improvements for the basis of
a patent free audio compression codec for the GNU project.

%package -n lame-mp3rtp
Summary:        MP3 Encoder for RTP Streaming
Group:          Productivity/Multimedia/Sound/Editors and Convertors
Requires:       libmp3lame%{soname} >= %{version}

%description -n lame-mp3rtp
LAME is an educational tool to be used for learning about MP3 encoding.
The goal of the LAME project is to use the open source model to improve the
psycho acoustics, noise shaping and speed of MP3.
Another goal of the LAME project is to use these improvements for the basis of
a patent free audio compression codec for the GNU project.

This package includes "mp3rtp", an MP3 encoder with RTP streaming of the output.

%if 0%{?gtk1}
%package -n lame-mp3x
Summary:        MP3 Frame Analyzer
Group:          Productivity/Multimedia/Sound/Visualization
Requires:       libmp3lame%{soname} >= %{version}

%description -n lame-mp3x
LAME is an educational tool to be used for learning about MP3 encoding.
The goal of the LAME project is to use the open source model to improve the
psycho acoustics, noise shaping and speed of MP3.
Another goal of the LAME project is to use these improvements for the basis of
a patent free audio compression codec for the GNU project.

This package includes "mp3x", an MP3 frame analyzer with a graphical
frontend.
%endif

%prep
%setup -q
%if 0%{?suse_version} > 1210
find . -type f \( -name configure.in -o -name Makefile.am \) | while read f; do
    perl -n -i.orig -e 's/\s+\S*ansi2knr// if /^AUTOMAKE_OPTIONS/ ; print unless /^AM_C_PROTOTYPES/' "$f"
done
%endif

%if %{?gtk1:0}%{!?gtk1:1}
# dirty
sed -i -e 's/AM_PATH_GTK.*/HAVE_GTK=no/' configure.in
sed -i -e s/@GTK_CFLAGS@// frontend/Makefile.am
%endif

%build
LIBS="-lm" \
CFLAGS="%{optflags}" \
%configure \
    --enable-nasm \
    --enable-decoder \
    --without-vorbis \
    --enable-analyzer=no \
    --enable-brhist \
    --disable-debug \
    --enable-mp3rtp \
%if 0%{?gtk1}
    --enable-mp3x \
%endif
    --with-fileio=lame \
    --enable-dynamic-frontends \
    --disable-rpath \
    --disable-static
 
%__make %{?_smp_flags} pkgdocdir=%{_defaultdocdir}/%{name}/

%install
%__make install pkgdocdir=%{_defaultdocdir}/%{name}/ DESTDIR="%{buildroot}"
rm -f %{buildroot}%{_libdir}/libmp3lame.la

for f in ChangeLog README TODO USAGE; do
    install -m0644 "$f" "%{buildroot}%{_defaultdocdir}/%{name}/"
done

%post   -n libmp3lame%{soname} -p /sbin/ldconfig
%postun -n libmp3lame%{soname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/lame
%{_mandir}/man1/lame.1*

%files doc
%defattr(-,root,root)
%{_defaultdocdir}/%{name}

%files -n libmp3lame%{soname}
%defattr(0644,root,root,0755)
%doc COPYING LICENSE
%{_libdir}/libmp3lame.so.%{soname}
%{_libdir}/libmp3lame.so.%{soname}.*

%files -n libmp3lame-devel
%defattr(-,root,root)
%doc API HACKING STYLEGUIDE
%{_includedir}/lame/
%{_libdir}/libmp3lame.so

%files -n lame-mp3rtp
%defattr(-,root,root)
%{_bindir}/mp3rtp

%if 0%{?gtk1}
%files -n lame-mp3x
%defattr(-,root,root)
%{_bindir}/mp3x
%endif

%changelog
* Fri Nov  1 2013 obs@botter.cc
- Fix logical issue in hvogel's fix
* Thu Oct 31 2013 hvogel@opensuse.org
- Fix the conditional building of gtk1 binaries
* Tue Oct 15 2013 obs@botter.cc
- Fix pkgconfig(gtk+-2.0) for >= 11.4
* Thu Jul 19 2012 reddwarf@opensuse.org
- Fix bug reporting link
- BuildRequires nasm only in x86-32 (there is no assembly available
  for other archs)
- Stop BuildRequiring flac-devel, it's not used
- Remove autoreconf call and related BuildRequires and patches
- Remove old compatibility Provides
- Run spec-cleaner
- Removed all patches (unneeded)
- Replace some documentation and let the build system install its
  own
* Tue Jul 17 2012 pascal.bleser@opensuse.org
- update to 3.99.5: fixed build on 12.2
* Tue Nov 22 2011 pascal.bleser@opensuse.org
- disable sndfile for IO, causes more issues than anything else (warnings and
  issues in several applications that use lame)
- lame-tgetstr.patch: fix build on openSUSE > 12.1, tput and friends are now in
  libtinfo
* Mon Mar  7 2011 pascal.bleser@opensuse.org
- add Gentoo patch that fixes reading from stdin
- add rpmlintrc
- split out documentation into subpackage
* Fri Jun 18 2010 lnussel@suse.de
- disable use of gtk in 11.3, was dropped
* Sat Mar 27 2010 pascal@links2linux.de
- update to 3.98.4:
  * fix for #2973877, a problem regarding the new drain code
* Sun Feb 28 2010 pascal@links2linux.de
- update to 3.98.3:
  * a very important interaction with the FhG decoder was fixed
  * the hip audio decoding library is used to perform a better job
    when reencoding MP3 files to MP3 files
  * bugs were worked around to improve compatibility with ffmpeg
  * many fixes were made regarding ID3 tags, including correct
    specification of the length of the tracks
- dropped cvs patch, merged upstream
* Fri Aug 21 2009 Manfred.Tremmel@iiv.de
- cleanups cvs patch
- removed static library
* Sat May 30 2009 Manfred.Tremmel@iiv.de
- patch from cvs to fix buffer problems with ffmpeg
* Tue Sep 23 2008 guru@unixtech.be
- added Authors: in description blocks
- use libsndfile for fileio, as it seems to be the prefered default now
- update to 3.98.2:
  * adds some quality improvements to the generated audio files
  * enables the user to choose fractional variable bitrate qualities
  * upgraded support for libsndfile1 (and, in turn, can use many file formats as input, including FLAC files)
  * includes many bugfixes, including peripheral tools for user convenience
* Sun Jul 13 2008 guru@unixtech.be
- added ldconfig in post and postun
- changed release to 0.pm.1 (instead of 1)
- split off shared library and -devel packages (still Requires by lame for
  backwards compatibility, may change later)
- fixed Group:
- added BuildRequires
- added debuginfo support
- revamped spec file
* Wed Dec 20 2006 henne@links2linux.de
- update to version 3.97
- build against libm for k3b
* Tue Feb 28 2006 henne@links2linux.de
- package missing include dir
* Sat Nov 27 2004 henne@links2linux.de
- make spec file lib/lib64 clean
* Sun Oct 17 2004 henne@links2linux.de
- updated to version 3.96.1
* Wed May  5 2004 henne@links2linux.de
- updated to version 3.95.1
* Sun Sep 28 2003 henne@links2linux.de
- updated to version 3.93.1
* Sun Aug 31 2003 henne@links2linux.de
- remove buildarch
* Sun Mar 23 2003 henne@links2linux.de
- compiled for 8.2
* Sun Sep 15 2002 henne@links2linux.de
- updated version to 3.92
* Mon Jan 28 2002 waldemar@links2linux.de
- new release
* Tue May 15 2001 waldemar@links2linux.de
- new beta
* Tue Jan 23 2001 waldemar@links2linux.de
- added mlame, script for multiple encoding with lame
* Thu Jan 11 2001 waldemar@links2linux.de
- compiled without ogg/vorbis support, because to buggy
* Wed Jan  3 2001 waldemar@links2linux.de
- first release
